summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorjan.nijtmans <nijtmans@users.sourceforge.net>2024-04-04 14:25:30 (GMT)
committerjan.nijtmans <nijtmans@users.sourceforge.net>2024-04-04 14:25:30 (GMT)
commit33e5497461ca8dfddc6aebcf7fcca7b561ac66b5 (patch)
tree26aedec2af4f1b07c6ea0968b26bf8743c4d9bdf
parentbd12eef0809ee8745b15fa5709711881f139f1e1 (diff)
parent70917f72ad4c11e43feaa04c20722162a032c84b (diff)
downloadtcl-33e5497461ca8dfddc6aebcf7fcca7b561ac66b5.zip
tcl-33e5497461ca8dfddc6aebcf7fcca7b561ac66b5.tar.gz
tcl-33e5497461ca8dfddc6aebcf7fcca7b561ac66b5.tar.bz2
Merge 8.7 (undid the encodingPtr -> encodingNamePtr change)
-rw-r--r--doc/Tcl_Main.38
-rw-r--r--generic/tcl.decls2
-rw-r--r--generic/tclCmdMZ.c2
-rw-r--r--generic/tclDecls.h4
-rw-r--r--generic/tclIOUtil.c2
-rw-r--r--generic/tclMain.c10
6 files changed, 14 insertions, 14 deletions
diff --git a/doc/Tcl_Main.3 b/doc/Tcl_Main.3
index 6883fab..6410450 100644
--- a/doc/Tcl_Main.3
+++ b/doc/Tcl_Main.3
@@ -24,7 +24,7 @@ Tcl_Main, Tcl_MainEx, Tcl_MainExW, Tcl_SetStartupScript, Tcl_GetStartupScript, T
\fBTcl_SetStartupScript\fR(\fIpath, encoding\fR)
.sp
Tcl_Obj *
-\fBTcl_GetStartupScript\fR(\fIencodingNamePtr\fR)
+\fBTcl_GetStartupScript\fR(\fIencodingPtr\fR)
.sp
\fBTcl_SetMainLoop\fR(\fImainLoopProc\fR)
.fi
@@ -46,7 +46,7 @@ The value for this argument is usually \fBTcl_AppInit\fR.
Name of file to use as startup script, or NULL.
.AP "const char" *encoding in
Encoding of file to use as startup script, or NULL.
-.AP "const char" **encodingNamePtr out
+.AP "const char" **encodingPtr out
If non-NULL, location to write a copy of the (const char *)
pointing to the encoding name.
.AP Tcl_MainLoopProc *mainLoopProc in
@@ -119,7 +119,7 @@ will not evaluate any startup script.
and encoding set by the most recent \fBTcl_SetStartupScript\fR
call in the same thread. The stored file name is returned,
and the stored encoding name is written to space pointed to
-by \fIencodingNamePtr\fR, when that is not NULL.
+by \fIencodingPtr\fR, when that is not NULL.
.PP
The file name and encoding values managed by the routines
\fBTcl_SetStartupScript\fR and \fBTcl_GetStartupScript\fR
@@ -215,7 +215,7 @@ embedders, the stubs table must be first initialized using one of
argument, and will increment the reference count of it.
.PP
\fBTcl_GetStartupScript\fR returns a value with reference count at least 1, or
-NULL. It's \fIencodingNamePtr\fR is also used (if non-NULL) to return a value with
+NULL. It's \fIencodingPtr\fR is also used (if non-NULL) to return a value with
a reference count at least 1, or NULL. In both cases, the owner of the values
is the current thread.
.SH "SEE ALSO"
diff --git a/generic/tcl.decls b/generic/tcl.decls
index 7078f7f..5f82a1c 100644
--- a/generic/tcl.decls
+++ b/generic/tcl.decls
@@ -2078,7 +2078,7 @@ declare 622 {
void Tcl_SetStartupScript(Tcl_Obj *path, const char *encoding)
}
declare 623 {
- Tcl_Obj *Tcl_GetStartupScript(const char **encodingNamePtr)
+ Tcl_Obj *Tcl_GetStartupScript(const char **encodingPtr)
}
# TIP#332 (half-close made public) aferrieux
diff --git a/generic/tclCmdMZ.c b/generic/tclCmdMZ.c
index 5173d5d..3effdf1 100644
--- a/generic/tclCmdMZ.c
+++ b/generic/tclCmdMZ.c
@@ -1110,7 +1110,7 @@ TclNRSourceObjCmd(
void *names = NULL;
if (objc < 2 || objc > 4) {
- Tcl_WrongNumArgs(interp, 1, objv, "?-encoding name? fileName");
+ Tcl_WrongNumArgs(interp, 1, objv, "?-encoding encoding? fileName");
return TCL_ERROR;
}
diff --git a/generic/tclDecls.h b/generic/tclDecls.h
index 64fc319..0d5bfe5 100644
--- a/generic/tclDecls.h
+++ b/generic/tclDecls.h
@@ -1664,7 +1664,7 @@ EXTERN int Tcl_ZlibStreamReset(Tcl_ZlibStream zshandle);
EXTERN void Tcl_SetStartupScript(Tcl_Obj *path,
const char *encoding);
/* 623 */
-EXTERN Tcl_Obj * Tcl_GetStartupScript(const char **encodingNamePtr);
+EXTERN Tcl_Obj * Tcl_GetStartupScript(const char **encodingPtr);
/* 624 */
EXTERN int Tcl_CloseEx(Tcl_Interp *interp, Tcl_Channel chan,
int flags);
@@ -2502,7 +2502,7 @@ typedef struct TclStubs {
int (*tcl_ZlibStreamClose) (Tcl_ZlibStream zshandle); /* 620 */
int (*tcl_ZlibStreamReset) (Tcl_ZlibStream zshandle); /* 621 */
void (*tcl_SetStartupScript) (Tcl_Obj *path, const char *encoding); /* 622 */
- Tcl_Obj * (*tcl_GetStartupScript) (const char **encodingNamePtr); /* 623 */
+ Tcl_Obj * (*tcl_GetStartupScript) (const char **encodingPtr); /* 623 */
int (*tcl_CloseEx) (Tcl_Interp *interp, Tcl_Channel chan, int flags); /* 624 */
int (*tcl_NRExprObj) (Tcl_Interp *interp, Tcl_Obj *objPtr, Tcl_Obj *resultPtr); /* 625 */
int (*tcl_NRSubstObj) (Tcl_Interp *interp, Tcl_Obj *objPtr, int flags); /* 626 */
diff --git a/generic/tclIOUtil.c b/generic/tclIOUtil.c
index e2be2eb..5a07533 100644
--- a/generic/tclIOUtil.c
+++ b/generic/tclIOUtil.c
@@ -1658,7 +1658,7 @@ TclGetOpenModeEx(
*
* Reads a file and evaluates it as a script.
*
- * Tcl_FSEvalFile is Tcl_FSEvalFileEx without the encoding argument.
+ * Tcl_FSEvalFile is Tcl_FSEvalFileEx without the encodingName argument.
*
* TclNREvalFile is an NRE-enabled version of Tcl_FSEvalFileEx.
*
diff --git a/generic/tclMain.c b/generic/tclMain.c
index f8ac2db..a93aabd 100644
--- a/generic/tclMain.c
+++ b/generic/tclMain.c
@@ -172,7 +172,7 @@ Tcl_SetStartupScript(
* The path of the startup script; NULL if none has been set.
*
* Side effects:
* If encodingNamePtr is not NULL, stores a (const char *) in it pointing to
* the encoding name registered for the startup script. Tcl retains
* ownership of the string, and may free it. Caller should make a copy
* for long-term use.
@@ -182,18 +182,18 @@ Tcl_SetStartupScript(
Tcl_Obj *
Tcl_GetStartupScript(
- const char **encodingNamePtr) /* When not NULL, points to storage for the
+ const char **encodingPtr) /* When not NULL, points to storage for the
* (const char *) that points to the
* registered encoding name for the startup
* script. */
{
ThreadSpecificData *tsdPtr = TCL_TSD_INIT(&dataKey);
- if (encodingNamePtr != NULL) {
+ if (encodingPtr != NULL) {
if (tsdPtr->encoding != NULL) {
- *encodingNamePtr = Tcl_GetString(tsdPtr->encoding);
+ *encodingPtr = Tcl_GetString(tsdPtr->encoding);
} else {
- *encodingNamePtr = NULL;
+ *encodingPtr = NULL;
}
}
return tsdPtr->path;
@@ -172,7 +172,7 @@ Tcl_SetStartupScript(
*
* Side effects:
- * If encodingNamePtr is not NULL, stores a (const char *) in it pointing to
+ * If encodingPtr is not NULL, stores a (const char *) in it pointing to
* the encoding name registered for the startup script. Tcl retains
* ownership of the string, and may free it. Caller should make a copy